// Copyright 2024 The Kubetail Authors
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

import { MockedProvider } from '@apollo/client/testing/react';
import type { MockedResponse } from '@apollo/client/testing';
import { render } from '@testing-library/react';
import React from 'react';
import { MemoryRouter } from 'react-router-dom';

import { DashboardCustomCache } from '@/apollo-client';

export const renderElement = (component: React.ReactElement, mocks?: MockedResponse[]) =>
  render(
    <MockedProvider
      mocks={mocks}
      cache={new DashboardCustomCache()}
      defaultOptions={{
        watchQuery: { fetchPolicy: 'cache-first' },
      }}
    >
      <MemoryRouter>{component}</MemoryRouter>
    </MockedProvider>,
  );
